@@ -32,9 +32,6 @@ from oslo_log import log as logging
 from oslo_utils import excutils
 import osprofiler.sqlalchemy
 from retrying import retry
-import six
-# NOTE(jokke): simplified transition to py3, behaves like py2 xrange
-from six.moves import range
 import sqlalchemy
 from sqlalchemy.ext.compiler import compiles
 from sqlalchemy import MetaData, Table
@@ -75,7 +72,7 @@ def _retry_on_deadlock(exc):
     """Decorator to retry a DB API call if Deadlock was received."""
 
     if isinstance(exc, db_exception.DBDeadlock):
-        LOG.warn(_LW("Deadlock detected. Retrying..."))
+        LOG.warning(_LW("Deadlock detected. Retrying..."))
         return True
     return False
 
@@ -132,7 +129,7 @@ def clear_db_env():
 
 def _check_mutate_authorization(context, image_ref):
     if not is_image_mutable(context, image_ref):
-        LOG.warn(_LW("Attempted to modify image user did not own."))
+        LOG.warning(_LW("Attempted to modify image user did not own."))
         msg = _("You do not own this image")
         if image_ref.visibility in ['private', 'shared']:
             exc_class = exception.Forbidden
@@ -365,7 +362,7 @@ def _paginate_query(query, model, limit, sort_keys, marker=None,
     if 'id' not in sort_keys:
         # TODO(justinsb): If this ever gives a false-positive, check
         # the actual primary key, rather than assuming its id
-        LOG.warn(_LW('Id not in sort_keys; is sort_keys unique?'))
+        LOG.warning(_LW('Id not in sort_keys; is sort_keys unique?'))
 
     assert(not (sort_dir and sort_dirs))  # nosec
     # nosec: This function runs safely if the assertion fails.
@@ -742,7 +739,8 @@ def _image_get_disk_usage_by_owner(owner, session, image_id=None):
 
     total = 0
     for i in images:
-        locations = [l for l in i.locations if l['status'] != 'deleted']
+        locations = [location for location in i.locations
+                     if location['status'] != 'deleted']
         total += (i.size * len(locations))
     return total
 
@@ -1087,7 +1085,7 @@ def image_location_update(context, image_id, location, session=None):
     except sa_orm.exc.NoResultFound:
         msg = (_("No location found with ID %(loc)s from image %(img)s") %
                dict(loc=loc_id, img=image_id))
-        LOG.warn(msg)
+        LOG.warning(msg)
         raise exception.NotFound(msg)
 
 
@@ -1113,7 +1111,7 @@ def image_location_delete(context, image_id, location_id, status,
     except sa_orm.exc.NoResultFound:
         msg = (_("No location found with ID %(loc)s from image %(img)s") %
                dict(loc=location_id, img=image_id))
-        LOG.warn(msg)
+        LOG.warning(msg)
         raise exception.NotFound(msg)
 
 
@@ -1175,7 +1173,7 @@ def _set_properties_for_image(context, image_ref, properties,
     for prop_ref in image_ref.properties:
         orig_properties[prop_ref.name] = prop_ref
 
-    for name, value in six.iteritems(properties):
+    for name, value in properties.items():
         prop_values = {'image_id': image_ref.id,
                        'name': name,
                        'value': value}
@@ -1513,9 +1511,12 @@ def purge_deleted_rows(context, age_in_days, max_rows, session=None):
     t = Table("tasks", metadata, autoload=True)
     ti = Table("task_info", metadata, autoload=True)
     joined_rec = ti.join(t, t.c.id == ti.c.task_id)
-    deleted_task_info = sql.select([ti.c.task_id],
-                                   t.c.deleted_at < deleted_age).\
-        select_from(joined_rec).order_by(t.c.deleted_at).limit(max_rows)
+    deleted_task_info = sql.\
+        select([ti.c.task_id], t.c.deleted_at < deleted_age).\
+        select_from(joined_rec).\
+        order_by(t.c.deleted_at)
+    if max_rows != -1:
+        deleted_task_info = deleted_task_info.limit(max_rows)
     delete_statement = DeleteFromSelect(ti, deleted_task_info,
                                         ti.c.task_id)
     LOG.info(_LI('Purging deleted rows older than %(age_in_days)d day(s) '
@@ -1527,7 +1528,7 @@ def purge_deleted_rows(context, age_in_days, max_rows, session=None):
     except (db_exception.DBError, db_exception.DBReferenceError) as ex:
         LOG.exception(_LE('DBError detected when force purging '
                           'table=%(table)s: %(error)s'),
-                      {'table': ti, 'error': six.text_type(ex)})
+                      {'table': ti, 'error': str(ex)})
         raise
 
     rows = result.rowcount
@@ -1559,9 +1560,10 @@ def purge_deleted_rows(context, age_in_days, max_rows, session=None):
         column = tab.c.id
         deleted_at_column = tab.c.deleted_at
 
-        query_delete = sql.select(
-            [column], deleted_at_column < deleted_age).order_by(
-            deleted_at_column).limit(max_rows)
+        query_delete = sql.select([column], deleted_at_column < deleted_age).\
+            order_by(deleted_at_column)
+        if max_rows != -1:
+            query_delete = query_delete.limit(max_rows)
 
         delete_statement = DeleteFromSelect(tab, query_delete, column)
 
@@ -1572,7 +1574,7 @@ def purge_deleted_rows(context, age_in_days, max_rows, session=None):
             with excutils.save_and_reraise_exception():
                 LOG.error(_LE('DBError detected when purging from '
                           "%(tablename)s: %(error)s"),
-                          {'tablename': tbl, 'error': six.text_type(ex)})
+                          {'tablename': tbl, 'error': str(ex)})
 
         rows = result.rowcount
         LOG.info(_LI('Deleted %(rows)d row(s) from table %(tbl)s'),
@@ -1603,9 +1605,11 @@ def purge_deleted_rows_from_images(context, age_in_days, max_rows,
     column = tab.c.id
     deleted_at_column = tab.c.deleted_at
 
-    query_delete = sql.select(
-        [column], deleted_at_column < deleted_age).order_by(
-        deleted_at_column).limit(max_rows)
+    query_delete = sql.\
+        select([column], deleted_at_column < deleted_age).\
+        order_by(deleted_at_column)
+    if max_rows != -1:
+        query_delete = query_delete.limit(max_rows)
 
     delete_statement = DeleteFromSelect(tab, query_delete, column)
 
@@ -1616,7 +1620,7 @@ def purge_deleted_rows_from_images(context, age_in_days, max_rows,
         with excutils.save_and_reraise_exception():
             LOG.error(_LE('DBError detected when purging from '
                       "%(tablename)s: %(error)s"),
-                      {'tablename': tbl, 'error': six.text_type(ex)})
+                      {'tablename': tbl, 'error': str(ex)})
 
     rows = result.rowcount
     LOG.info(_LI('Deleted %(rows)d row(s) from table %(tbl)s'),
@@ -2183,11 +2187,11 @@ def metadef_tag_create(context, namespace_name, tag_dict,
 
 
 def metadef_tag_create_tags(context, namespace_name, tag_list,
-                            session=None):
+                            can_append=False, session=None):
     """Create a metadata-schema tag or raise if it already exists."""
     session = get_session()
     return metadef_tag_api.create_tags(
-        context, namespace_name, tag_list, session)
+        context, namespace_name, tag_list, can_append, session)
 
 
 @utils.no_4byte_params
