@@ -12,13 +12,12 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
+
+import http.client as http
 from unittest.mock import patch
 
 from oslo_policy import policy
 from oslo_utils.fixture import uuidsentinel as uuids
-# NOTE(jokke): simplified transition to py3, behaves like py2 xrange
-from six.moves import http_client as http
-from six.moves import range
 import testtools
 import webob
 
@@ -410,7 +409,8 @@ class TestCacheMiddlewareProcessResponse(base.IsolatedUnitTest):
         rules = {
             "restricted":
             "not ('test_1234':%(x_test_key)s and role:_member_)",
-            "download_image": "role:admin or rule:restricted"
+            "download_image": "role:admin or rule:restricted",
+            "get_image": ""
         }
         self.set_policy_rules(rules)
         cache_filter.policy = glance.api.policy.Enforcer(
